galchemy/ast/join

Types

Represents a table join with its join kind and join predicate.

pub type Join {
  Join(
    kind: JoinKind,
    table: schema.Table,
    on: predicate.Predicate,
  )
}

Constructors

Enumerates the join kinds currently supported by the AST.

pub type JoinKind {
  InnerJoin
  LeftJoin
}

Constructors

  • InnerJoin
  • LeftJoin
Search Document