galchemy/ast/schema

Types

Wraps column metadata with a phantom type for typed query construction.

pub type Column(a) {
  Column(meta: ColumnMeta)
}

Constructors

Identifies a concrete column within a specific table reference.

pub type ColumnMeta {
  ColumnMeta(table: Table, name: String)
}

Constructors

  • ColumnMeta(table: Table, name: String)

Represents a database table reference with an optional SQL alias.

pub type Table {
  Table(
    schema: option.Option(String),
    name: String,
    alias: option.Option(String),
  )
}

Constructors

Search Document